@@ -182,7 +182,7 @@ impl AVCodecContext {
         };
         match unsafe { ffi::avcodec_send_packet(self.as_mut_ptr(), packet_ptr) }.upgrade() {
             Ok(_) => Ok(()),
-            Err(AVERROR_EAGAIN) => Err(RsmpegError::SendPacketAgainError),
+            Err(AVERROR_EAGAIN) => Err(RsmpegError::DecoderFullError),
             Err(ffi::AVERROR_EOF) => Err(RsmpegError::DecoderFlushedError),
             Err(x) => Err(RsmpegError::SendPacketError(x)),
         }
